diff --git a/data-src/appversion b/data-src/appversion
index d003324..9c25f93 100644
--- a/data-src/appversion
+++ b/data-src/appversion
@@ -1 +1 @@
-3.0.12
\ No newline at end of file
+3.0.13
\ No newline at end of file
diff --git a/data-src/index.html b/data-src/index.html
index d28b16d..4cc3eef 100644
--- a/data-src/index.html
+++ b/data-src/index.html
@@ -8,9 +8,9 @@
-
-
-
+
+
+
@@ -114,7 +114,7 @@
rel="apple-touch-startup-image">
-
+
diff --git a/src/ConfigSettings.h b/src/ConfigSettings.h
index 67bd9c9..5ab546e 100644
--- a/src/ConfigSettings.h
+++ b/src/ConfigSettings.h
@@ -7,7 +7,7 @@
#include "WResp.h"
#ifndef FW_VERSION
- #define FW_VERSION "v3.0.12" // Fallback if app_version.py script fails
+ #define FW_VERSION "v3.0.13" // Fallback if app_version.py script fails
#endif
enum class conn_types_t : byte {
diff --git a/data-src/index.js b/data-src/index.js
index 66a4b6d..cf95820 100644
--- a/data-src/index.js
+++ b/data-src/index.js
@@ -1283,7 +1283,7 @@ class Security {
}
var security = new Security();
// let appVersion = 'v3.0.12'; // Default placeholder
async function getAppVersion() {
try {
const response = await fetch('/appversion?v='+Date.now());
@@ -1296,7 +1296,7 @@ async function getAppVersion() {
// Trigger any UI updates here
} catch (error) {
console.error("Error loading App version:", error);
- appVersion = 'v3.0.12'; // Default placeholder
+ appVersion = 'v3.0.13'; // Default placeholder
}
return appVersion;
}
@@ -1283,7 +1283,7 @@ class Security {
}
var security = new Security();
-// let appVersion = 'v3.0.12'; // Default placeholder
+// let appVersion = 'v3.0.13'; // Default placeholder
async function getAppVersion() {
try {